@@ -3,23 +3,10 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use Test::Apache2::Server;
-
-sub import {
-    {
-        package Apache2::ServerUtil;
-
-        sub server_root {
-            '';
-        }
-
-        sub restart_count {
-            0;
-        }
-    }
-}
+use Test::Apache2::Override;
 
 1;
 __END__
